# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBillingPlanInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'discount_info': 'BTDiscountInfo',
        'group': 'str',
        'trial_period_days': 'int',
        'client_id': 'str',
        'hidden': 'bool',
        'onshape_plan': 'bool',
        'description': 'str',
        'deprecated': 'bool',
        'plan_type': 'int',
        'consumable_quantity': 'int',
        'amount_cents': 'int',
        'interval': 'str',
        'application_id': 'str',
        'company_plan': 'bool',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'discount_info': 'discountInfo',
        'group': 'group',
        'trial_period_days': 'trialPeriodDays',
        'client_id': 'clientId',
        'hidden': 'hidden',
        'onshape_plan': 'onshapePlan',
        'description': 'description',
        'deprecated': 'deprecated',
        'plan_type': 'planType',
        'consumable_quantity': 'consumableQuantity',
        'amount_cents': 'amountCents',
        'interval': 'interval',
        'application_id': 'applicationId',
        'company_plan': 'companyPlan',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, discount_info=None, group=None, trial_period_days=None, client_id=None, hidden=None, onshape_plan=None, description=None, deprecated=None, plan_type=None, consumable_quantity=None, amount_cents=None, interval=None, application_id=None, company_plan=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTBillingPlanInfo - a model defined in OpenAPI"""  # noqa: E501

        self._discount_info = None
        self._group = None
        self._trial_period_days = None
        self._client_id = None
        self._hidden = None
        self._onshape_plan = None
        self._description = None
        self._deprecated = None
        self._plan_type = None
        self._consumable_quantity = None
        self._amount_cents = None
        self._interval = None
        self._application_id = None
        self._company_plan = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if discount_info is not None:
            self.discount_info = discount_info
        if group is not None:
            self.group = group
        if trial_period_days is not None:
            self.trial_period_days = trial_period_days
        if client_id is not None:
            self.client_id = client_id
        if hidden is not None:
            self.hidden = hidden
        if onshape_plan is not None:
            self.onshape_plan = onshape_plan
        if description is not None:
            self.description = description
        if deprecated is not None:
            self.deprecated = deprecated
        if plan_type is not None:
            self.plan_type = plan_type
        if consumable_quantity is not None:
            self.consumable_quantity = consumable_quantity
        if amount_cents is not None:
            self.amount_cents = amount_cents
        if interval is not None:
            self.interval = interval
        if application_id is not None:
            self.application_id = application_id
        if company_plan is not None:
            self.company_plan = company_plan
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def discount_info(self):
        """Gets the discount_info of this BTBillingPlanInfo.  # noqa: E501


        :return: The discount_info of this BTBillingPlanInfo.  # noqa: E501
        :rtype: BTDiscountInfo
        """
        return self._discount_info

    @discount_info.setter
    def discount_info(self, discount_info):
        """Sets the discount_info of this BTBillingPlanInfo.


        :param discount_info: The discount_info of this BTBillingPlanInfo.  # noqa: E501
        :type: BTDiscountInfo
        """

        self._discount_info = discount_info

    @property
    def group(self):
        """Gets the group of this BTBillingPlanInfo.  # noqa: E501


        :return: The group of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this BTBillingPlanInfo.


        :param group: The group of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._group = group

    @property
    def trial_period_days(self):
        """Gets the trial_period_days of this BTBillingPlanInfo.  # noqa: E501


        :return: The trial_period_days of this BTBillingPlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._trial_period_days

    @trial_period_days.setter
    def trial_period_days(self, trial_period_days):
        """Sets the trial_period_days of this BTBillingPlanInfo.


        :param trial_period_days: The trial_period_days of this BTBillingPlanInfo.  # noqa: E501
        :type: int
        """

        self._trial_period_days = trial_period_days

    @property
    def client_id(self):
        """Gets the client_id of this BTBillingPlanInfo.  # noqa: E501


        :return: The client_id of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BTBillingPlanInfo.


        :param client_id: The client_id of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def hidden(self):
        """Gets the hidden of this BTBillingPlanInfo.  # noqa: E501


        :return: The hidden of this BTBillingPlanInfo.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this BTBillingPlanInfo.


        :param hidden: The hidden of this BTBillingPlanInfo.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def onshape_plan(self):
        """Gets the onshape_plan of this BTBillingPlanInfo.  # noqa: E501


        :return: The onshape_plan of this BTBillingPlanInfo.  # noqa: E501
        :rtype: bool
        """
        return self._onshape_plan

    @onshape_plan.setter
    def onshape_plan(self, onshape_plan):
        """Sets the onshape_plan of this BTBillingPlanInfo.


        :param onshape_plan: The onshape_plan of this BTBillingPlanInfo.  # noqa: E501
        :type: bool
        """

        self._onshape_plan = onshape_plan

    @property
    def description(self):
        """Gets the description of this BTBillingPlanInfo.  # noqa: E501


        :return: The description of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTBillingPlanInfo.


        :param description: The description of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def deprecated(self):
        """Gets the deprecated of this BTBillingPlanInfo.  # noqa: E501


        :return: The deprecated of this BTBillingPlanInfo.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this BTBillingPlanInfo.


        :param deprecated: The deprecated of this BTBillingPlanInfo.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    @property
    def plan_type(self):
        """Gets the plan_type of this BTBillingPlanInfo.  # noqa: E501


        :return: The plan_type of this BTBillingPlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """Sets the plan_type of this BTBillingPlanInfo.


        :param plan_type: The plan_type of this BTBillingPlanInfo.  # noqa: E501
        :type: int
        """

        self._plan_type = plan_type

    @property
    def consumable_quantity(self):
        """Gets the consumable_quantity of this BTBillingPlanInfo.  # noqa: E501


        :return: The consumable_quantity of this BTBillingPlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._consumable_quantity

    @consumable_quantity.setter
    def consumable_quantity(self, consumable_quantity):
        """Sets the consumable_quantity of this BTBillingPlanInfo.


        :param consumable_quantity: The consumable_quantity of this BTBillingPlanInfo.  # noqa: E501
        :type: int
        """

        self._consumable_quantity = consumable_quantity

    @property
    def amount_cents(self):
        """Gets the amount_cents of this BTBillingPlanInfo.  # noqa: E501


        :return: The amount_cents of this BTBillingPlanInfo.  # noqa: E501
        :rtype: int
        """
        return self._amount_cents

    @amount_cents.setter
    def amount_cents(self, amount_cents):
        """Sets the amount_cents of this BTBillingPlanInfo.


        :param amount_cents: The amount_cents of this BTBillingPlanInfo.  # noqa: E501
        :type: int
        """

        self._amount_cents = amount_cents

    @property
    def interval(self):
        """Gets the interval of this BTBillingPlanInfo.  # noqa: E501


        :return: The interval of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this BTBillingPlanInfo.


        :param interval: The interval of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._interval = interval

    @property
    def application_id(self):
        """Gets the application_id of this BTBillingPlanInfo.  # noqa: E501


        :return: The application_id of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this BTBillingPlanInfo.


        :param application_id: The application_id of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def company_plan(self):
        """Gets the company_plan of this BTBillingPlanInfo.  # noqa: E501


        :return: The company_plan of this BTBillingPlanInfo.  # noqa: E501
        :rtype: bool
        """
        return self._company_plan

    @company_plan.setter
    def company_plan(self, company_plan):
        """Sets the company_plan of this BTBillingPlanInfo.


        :param company_plan: The company_plan of this BTBillingPlanInfo.  # noqa: E501
        :type: bool
        """

        self._company_plan = company_plan

    @property
    def name(self):
        """Gets the name of this BTBillingPlanInfo.  # noqa: E501


        :return: The name of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTBillingPlanInfo.


        :param name: The name of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTBillingPlanInfo.  # noqa: E501


        :return: The id of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTBillingPlanInfo.


        :param id: The id of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTBillingPlanInfo.  # noqa: E501


        :return: The href of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTBillingPlanInfo.


        :param href: The href of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTBillingPlanInfo.  # noqa: E501


        :return: The view_ref of this BTBillingPlanInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTBillingPlanInfo.


        :param view_ref: The view_ref of this BTBillingPlanInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBillingPlanInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
