# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTIdentityManagementParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'metadata_must_be_signed': 'bool',
        'enabled': 'bool',
        'provider_type': 'int',
        'idp_certificate': 'str',
        'idp_entity_id': 'str',
        'idp_redirect_url': 'str'
    }

    attribute_map = {
        'name': 'name',
        'metadata_must_be_signed': 'metadataMustBeSigned',
        'enabled': 'enabled',
        'provider_type': 'providerType',
        'idp_certificate': 'idpCertificate',
        'idp_entity_id': 'idpEntityId',
        'idp_redirect_url': 'idpRedirectURL'
    }

    def __init__(self, name=None, metadata_must_be_signed=None, enabled=None, provider_type=None, idp_certificate=None, idp_entity_id=None, idp_redirect_url=None):  # noqa: E501
        """BTIdentityManagementParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._metadata_must_be_signed = None
        self._enabled = None
        self._provider_type = None
        self._idp_certificate = None
        self._idp_entity_id = None
        self._idp_redirect_url = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if metadata_must_be_signed is not None:
            self.metadata_must_be_signed = metadata_must_be_signed
        if enabled is not None:
            self.enabled = enabled
        if provider_type is not None:
            self.provider_type = provider_type
        if idp_certificate is not None:
            self.idp_certificate = idp_certificate
        if idp_entity_id is not None:
            self.idp_entity_id = idp_entity_id
        if idp_redirect_url is not None:
            self.idp_redirect_url = idp_redirect_url

    @property
    def name(self):
        """Gets the name of this BTIdentityManagementParams.  # noqa: E501


        :return: The name of this BTIdentityManagementParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTIdentityManagementParams.


        :param name: The name of this BTIdentityManagementParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def metadata_must_be_signed(self):
        """Gets the metadata_must_be_signed of this BTIdentityManagementParams.  # noqa: E501


        :return: The metadata_must_be_signed of this BTIdentityManagementParams.  # noqa: E501
        :rtype: bool
        """
        return self._metadata_must_be_signed

    @metadata_must_be_signed.setter
    def metadata_must_be_signed(self, metadata_must_be_signed):
        """Sets the metadata_must_be_signed of this BTIdentityManagementParams.


        :param metadata_must_be_signed: The metadata_must_be_signed of this BTIdentityManagementParams.  # noqa: E501
        :type: bool
        """

        self._metadata_must_be_signed = metadata_must_be_signed

    @property
    def enabled(self):
        """Gets the enabled of this BTIdentityManagementParams.  # noqa: E501


        :return: The enabled of this BTIdentityManagementParams.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this BTIdentityManagementParams.


        :param enabled: The enabled of this BTIdentityManagementParams.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def provider_type(self):
        """Gets the provider_type of this BTIdentityManagementParams.  # noqa: E501


        :return: The provider_type of this BTIdentityManagementParams.  # noqa: E501
        :rtype: int
        """
        return self._provider_type

    @provider_type.setter
    def provider_type(self, provider_type):
        """Sets the provider_type of this BTIdentityManagementParams.


        :param provider_type: The provider_type of this BTIdentityManagementParams.  # noqa: E501
        :type: int
        """

        self._provider_type = provider_type

    @property
    def idp_certificate(self):
        """Gets the idp_certificate of this BTIdentityManagementParams.  # noqa: E501


        :return: The idp_certificate of this BTIdentityManagementParams.  # noqa: E501
        :rtype: str
        """
        return self._idp_certificate

    @idp_certificate.setter
    def idp_certificate(self, idp_certificate):
        """Sets the idp_certificate of this BTIdentityManagementParams.


        :param idp_certificate: The idp_certificate of this BTIdentityManagementParams.  # noqa: E501
        :type: str
        """

        self._idp_certificate = idp_certificate

    @property
    def idp_entity_id(self):
        """Gets the idp_entity_id of this BTIdentityManagementParams.  # noqa: E501


        :return: The idp_entity_id of this BTIdentityManagementParams.  # noqa: E501
        :rtype: str
        """
        return self._idp_entity_id

    @idp_entity_id.setter
    def idp_entity_id(self, idp_entity_id):
        """Sets the idp_entity_id of this BTIdentityManagementParams.


        :param idp_entity_id: The idp_entity_id of this BTIdentityManagementParams.  # noqa: E501
        :type: str
        """

        self._idp_entity_id = idp_entity_id

    @property
    def idp_redirect_url(self):
        """Gets the idp_redirect_url of this BTIdentityManagementParams.  # noqa: E501


        :return: The idp_redirect_url of this BTIdentityManagementParams.  # noqa: E501
        :rtype: str
        """
        return self._idp_redirect_url

    @idp_redirect_url.setter
    def idp_redirect_url(self, idp_redirect_url):
        """Sets the idp_redirect_url of this BTIdentityManagementParams.


        :param idp_redirect_url: The idp_redirect_url of this BTIdentityManagementParams.  # noqa: E501
        :type: str
        """

        self._idp_redirect_url = idp_redirect_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTIdentityManagementParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
