# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMetadataPropertyParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'array': 'bool',
        'name': 'str',
        'id': 'str',
        'description': 'str',
        'namespace': 'str',
        'owner_id': 'str',
        'value_type': 'int',
        'owner_type_ordinal': 'int',
        'property_config_param_list': 'list[BTMetadataPropertyConfigParams]',
        'object_def_name': 'str',
        'blob_mime_type': 'str',
        'editable_in_version': 'bool',
        'editable_in_microversion': 'bool',
        'ui_readonly_in_version': 'bool',
        'ui_readonly_in_microversion': 'bool',
        'search_boost': 'float'
    }

    attribute_map = {
        'array': 'array',
        'name': 'name',
        'id': 'id',
        'description': 'description',
        'namespace': 'namespace',
        'owner_id': 'ownerId',
        'value_type': 'valueType',
        'owner_type_ordinal': 'ownerTypeOrdinal',
        'property_config_param_list': 'propertyConfigParamList',
        'object_def_name': 'objectDefName',
        'blob_mime_type': 'blobMimeType',
        'editable_in_version': 'editableInVersion',
        'editable_in_microversion': 'editableInMicroversion',
        'ui_readonly_in_version': 'uiReadonlyInVersion',
        'ui_readonly_in_microversion': 'uiReadonlyInMicroversion',
        'search_boost': 'searchBoost'
    }

    def __init__(self, array=None, name=None, id=None, description=None, namespace=None, owner_id=None, value_type=None, owner_type_ordinal=None, property_config_param_list=None, object_def_name=None, blob_mime_type=None, editable_in_version=None, editable_in_microversion=None, ui_readonly_in_version=None, ui_readonly_in_microversion=None, search_boost=None):  # noqa: E501
        """BTMetadataPropertyParams - a model defined in OpenAPI"""  # noqa: E501

        self._array = None
        self._name = None
        self._id = None
        self._description = None
        self._namespace = None
        self._owner_id = None
        self._value_type = None
        self._owner_type_ordinal = None
        self._property_config_param_list = None
        self._object_def_name = None
        self._blob_mime_type = None
        self._editable_in_version = None
        self._editable_in_microversion = None
        self._ui_readonly_in_version = None
        self._ui_readonly_in_microversion = None
        self._search_boost = None
        self.discriminator = None

        if array is not None:
            self.array = array
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if description is not None:
            self.description = description
        if namespace is not None:
            self.namespace = namespace
        if owner_id is not None:
            self.owner_id = owner_id
        if value_type is not None:
            self.value_type = value_type
        if owner_type_ordinal is not None:
            self.owner_type_ordinal = owner_type_ordinal
        if property_config_param_list is not None:
            self.property_config_param_list = property_config_param_list
        if object_def_name is not None:
            self.object_def_name = object_def_name
        if blob_mime_type is not None:
            self.blob_mime_type = blob_mime_type
        if editable_in_version is not None:
            self.editable_in_version = editable_in_version
        if editable_in_microversion is not None:
            self.editable_in_microversion = editable_in_microversion
        if ui_readonly_in_version is not None:
            self.ui_readonly_in_version = ui_readonly_in_version
        if ui_readonly_in_microversion is not None:
            self.ui_readonly_in_microversion = ui_readonly_in_microversion
        if search_boost is not None:
            self.search_boost = search_boost

    @property
    def array(self):
        """Gets the array of this BTMetadataPropertyParams.  # noqa: E501


        :return: The array of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._array

    @array.setter
    def array(self, array):
        """Sets the array of this BTMetadataPropertyParams.


        :param array: The array of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._array = array

    @property
    def name(self):
        """Gets the name of this BTMetadataPropertyParams.  # noqa: E501


        :return: The name of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTMetadataPropertyParams.


        :param name: The name of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTMetadataPropertyParams.  # noqa: E501


        :return: The id of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTMetadataPropertyParams.


        :param id: The id of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def description(self):
        """Gets the description of this BTMetadataPropertyParams.  # noqa: E501


        :return: The description of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTMetadataPropertyParams.


        :param description: The description of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def namespace(self):
        """Gets the namespace of this BTMetadataPropertyParams.  # noqa: E501


        :return: The namespace of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BTMetadataPropertyParams.


        :param namespace: The namespace of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def owner_id(self):
        """Gets the owner_id of this BTMetadataPropertyParams.  # noqa: E501


        :return: The owner_id of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTMetadataPropertyParams.


        :param owner_id: The owner_id of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def value_type(self):
        """Gets the value_type of this BTMetadataPropertyParams.  # noqa: E501


        :return: The value_type of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: int
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this BTMetadataPropertyParams.


        :param value_type: The value_type of this BTMetadataPropertyParams.  # noqa: E501
        :type: int
        """

        self._value_type = value_type

    @property
    def owner_type_ordinal(self):
        """Gets the owner_type_ordinal of this BTMetadataPropertyParams.  # noqa: E501


        :return: The owner_type_ordinal of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: int
        """
        return self._owner_type_ordinal

    @owner_type_ordinal.setter
    def owner_type_ordinal(self, owner_type_ordinal):
        """Sets the owner_type_ordinal of this BTMetadataPropertyParams.


        :param owner_type_ordinal: The owner_type_ordinal of this BTMetadataPropertyParams.  # noqa: E501
        :type: int
        """

        self._owner_type_ordinal = owner_type_ordinal

    @property
    def property_config_param_list(self):
        """Gets the property_config_param_list of this BTMetadataPropertyParams.  # noqa: E501


        :return: The property_config_param_list of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: list[BTMetadataPropertyConfigParams]
        """
        return self._property_config_param_list

    @property_config_param_list.setter
    def property_config_param_list(self, property_config_param_list):
        """Sets the property_config_param_list of this BTMetadataPropertyParams.


        :param property_config_param_list: The property_config_param_list of this BTMetadataPropertyParams.  # noqa: E501
        :type: list[BTMetadataPropertyConfigParams]
        """

        self._property_config_param_list = property_config_param_list

    @property
    def object_def_name(self):
        """Gets the object_def_name of this BTMetadataPropertyParams.  # noqa: E501


        :return: The object_def_name of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._object_def_name

    @object_def_name.setter
    def object_def_name(self, object_def_name):
        """Sets the object_def_name of this BTMetadataPropertyParams.


        :param object_def_name: The object_def_name of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._object_def_name = object_def_name

    @property
    def blob_mime_type(self):
        """Gets the blob_mime_type of this BTMetadataPropertyParams.  # noqa: E501


        :return: The blob_mime_type of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: str
        """
        return self._blob_mime_type

    @blob_mime_type.setter
    def blob_mime_type(self, blob_mime_type):
        """Sets the blob_mime_type of this BTMetadataPropertyParams.


        :param blob_mime_type: The blob_mime_type of this BTMetadataPropertyParams.  # noqa: E501
        :type: str
        """

        self._blob_mime_type = blob_mime_type

    @property
    def editable_in_version(self):
        """Gets the editable_in_version of this BTMetadataPropertyParams.  # noqa: E501


        :return: The editable_in_version of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._editable_in_version

    @editable_in_version.setter
    def editable_in_version(self, editable_in_version):
        """Sets the editable_in_version of this BTMetadataPropertyParams.


        :param editable_in_version: The editable_in_version of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._editable_in_version = editable_in_version

    @property
    def editable_in_microversion(self):
        """Gets the editable_in_microversion of this BTMetadataPropertyParams.  # noqa: E501


        :return: The editable_in_microversion of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._editable_in_microversion

    @editable_in_microversion.setter
    def editable_in_microversion(self, editable_in_microversion):
        """Sets the editable_in_microversion of this BTMetadataPropertyParams.


        :param editable_in_microversion: The editable_in_microversion of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._editable_in_microversion = editable_in_microversion

    @property
    def ui_readonly_in_version(self):
        """Gets the ui_readonly_in_version of this BTMetadataPropertyParams.  # noqa: E501


        :return: The ui_readonly_in_version of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._ui_readonly_in_version

    @ui_readonly_in_version.setter
    def ui_readonly_in_version(self, ui_readonly_in_version):
        """Sets the ui_readonly_in_version of this BTMetadataPropertyParams.


        :param ui_readonly_in_version: The ui_readonly_in_version of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._ui_readonly_in_version = ui_readonly_in_version

    @property
    def ui_readonly_in_microversion(self):
        """Gets the ui_readonly_in_microversion of this BTMetadataPropertyParams.  # noqa: E501


        :return: The ui_readonly_in_microversion of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: bool
        """
        return self._ui_readonly_in_microversion

    @ui_readonly_in_microversion.setter
    def ui_readonly_in_microversion(self, ui_readonly_in_microversion):
        """Sets the ui_readonly_in_microversion of this BTMetadataPropertyParams.


        :param ui_readonly_in_microversion: The ui_readonly_in_microversion of this BTMetadataPropertyParams.  # noqa: E501
        :type: bool
        """

        self._ui_readonly_in_microversion = ui_readonly_in_microversion

    @property
    def search_boost(self):
        """Gets the search_boost of this BTMetadataPropertyParams.  # noqa: E501


        :return: The search_boost of this BTMetadataPropertyParams.  # noqa: E501
        :rtype: float
        """
        return self._search_boost

    @search_boost.setter
    def search_boost(self, search_boost):
        """Sets the search_boost of this BTMetadataPropertyParams.


        :param search_boost: The search_boost of this BTMetadataPropertyParams.  # noqa: E501
        :type: float
        """

        self._search_boost = search_boost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMetadataPropertyParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
