# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.93
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWorkflowInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'actions': 'list[BTActionInfo]',
        'state': 'BTWorkflowStateInfo',
        'rejected_by': 'list[str]',
        'is_setup': 'bool',
        'approved_by': 'list[str]',
        'is_frozen': 'bool',
        'is_initial_state': 'bool',
        'approver_ids': 'list[str]',
        'notifier_ids': 'list[str]',
        'workflow_id': 'str',
        'metadata_state': 'str',
        'is_discarded': 'bool'
    }

    attribute_map = {
        'actions': 'actions',
        'state': 'state',
        'rejected_by': 'rejectedBy',
        'is_setup': 'isSetup',
        'approved_by': 'approvedBy',
        'is_frozen': 'isFrozen',
        'is_initial_state': 'isInitialState',
        'approver_ids': 'approverIds',
        'notifier_ids': 'notifierIds',
        'workflow_id': 'workflowId',
        'metadata_state': 'metadataState',
        'is_discarded': 'isDiscarded'
    }

    def __init__(self, actions=None, state=None, rejected_by=None, is_setup=None, approved_by=None, is_frozen=None, is_initial_state=None, approver_ids=None, notifier_ids=None, workflow_id=None, metadata_state=None, is_discarded=None):  # noqa: E501
        """BTWorkflowInfo - a model defined in OpenAPI"""  # noqa: E501

        self._actions = None
        self._state = None
        self._rejected_by = None
        self._is_setup = None
        self._approved_by = None
        self._is_frozen = None
        self._is_initial_state = None
        self._approver_ids = None
        self._notifier_ids = None
        self._workflow_id = None
        self._metadata_state = None
        self._is_discarded = None
        self.discriminator = None

        if actions is not None:
            self.actions = actions
        if state is not None:
            self.state = state
        if rejected_by is not None:
            self.rejected_by = rejected_by
        if is_setup is not None:
            self.is_setup = is_setup
        if approved_by is not None:
            self.approved_by = approved_by
        if is_frozen is not None:
            self.is_frozen = is_frozen
        if is_initial_state is not None:
            self.is_initial_state = is_initial_state
        if approver_ids is not None:
            self.approver_ids = approver_ids
        if notifier_ids is not None:
            self.notifier_ids = notifier_ids
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if metadata_state is not None:
            self.metadata_state = metadata_state
        if is_discarded is not None:
            self.is_discarded = is_discarded

    @property
    def actions(self):
        """Gets the actions of this BTWorkflowInfo.  # noqa: E501


        :return: The actions of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[BTActionInfo]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this BTWorkflowInfo.


        :param actions: The actions of this BTWorkflowInfo.  # noqa: E501
        :type: list[BTActionInfo]
        """

        self._actions = actions

    @property
    def state(self):
        """Gets the state of this BTWorkflowInfo.  # noqa: E501


        :return: The state of this BTWorkflowInfo.  # noqa: E501
        :rtype: BTWorkflowStateInfo
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTWorkflowInfo.


        :param state: The state of this BTWorkflowInfo.  # noqa: E501
        :type: BTWorkflowStateInfo
        """

        self._state = state

    @property
    def rejected_by(self):
        """Gets the rejected_by of this BTWorkflowInfo.  # noqa: E501


        :return: The rejected_by of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._rejected_by

    @rejected_by.setter
    def rejected_by(self, rejected_by):
        """Sets the rejected_by of this BTWorkflowInfo.


        :param rejected_by: The rejected_by of this BTWorkflowInfo.  # noqa: E501
        :type: list[str]
        """

        self._rejected_by = rejected_by

    @property
    def is_setup(self):
        """Gets the is_setup of this BTWorkflowInfo.  # noqa: E501


        :return: The is_setup of this BTWorkflowInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_setup

    @is_setup.setter
    def is_setup(self, is_setup):
        """Sets the is_setup of this BTWorkflowInfo.


        :param is_setup: The is_setup of this BTWorkflowInfo.  # noqa: E501
        :type: bool
        """

        self._is_setup = is_setup

    @property
    def approved_by(self):
        """Gets the approved_by of this BTWorkflowInfo.  # noqa: E501


        :return: The approved_by of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._approved_by

    @approved_by.setter
    def approved_by(self, approved_by):
        """Sets the approved_by of this BTWorkflowInfo.


        :param approved_by: The approved_by of this BTWorkflowInfo.  # noqa: E501
        :type: list[str]
        """

        self._approved_by = approved_by

    @property
    def is_frozen(self):
        """Gets the is_frozen of this BTWorkflowInfo.  # noqa: E501


        :return: The is_frozen of this BTWorkflowInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_frozen

    @is_frozen.setter
    def is_frozen(self, is_frozen):
        """Sets the is_frozen of this BTWorkflowInfo.


        :param is_frozen: The is_frozen of this BTWorkflowInfo.  # noqa: E501
        :type: bool
        """

        self._is_frozen = is_frozen

    @property
    def is_initial_state(self):
        """Gets the is_initial_state of this BTWorkflowInfo.  # noqa: E501


        :return: The is_initial_state of this BTWorkflowInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_initial_state

    @is_initial_state.setter
    def is_initial_state(self, is_initial_state):
        """Sets the is_initial_state of this BTWorkflowInfo.


        :param is_initial_state: The is_initial_state of this BTWorkflowInfo.  # noqa: E501
        :type: bool
        """

        self._is_initial_state = is_initial_state

    @property
    def approver_ids(self):
        """Gets the approver_ids of this BTWorkflowInfo.  # noqa: E501


        :return: The approver_ids of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._approver_ids

    @approver_ids.setter
    def approver_ids(self, approver_ids):
        """Sets the approver_ids of this BTWorkflowInfo.


        :param approver_ids: The approver_ids of this BTWorkflowInfo.  # noqa: E501
        :type: list[str]
        """

        self._approver_ids = approver_ids

    @property
    def notifier_ids(self):
        """Gets the notifier_ids of this BTWorkflowInfo.  # noqa: E501


        :return: The notifier_ids of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._notifier_ids

    @notifier_ids.setter
    def notifier_ids(self, notifier_ids):
        """Sets the notifier_ids of this BTWorkflowInfo.


        :param notifier_ids: The notifier_ids of this BTWorkflowInfo.  # noqa: E501
        :type: list[str]
        """

        self._notifier_ids = notifier_ids

    @property
    def workflow_id(self):
        """Gets the workflow_id of this BTWorkflowInfo.  # noqa: E501


        :return: The workflow_id of this BTWorkflowInfo.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this BTWorkflowInfo.


        :param workflow_id: The workflow_id of this BTWorkflowInfo.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    @property
    def metadata_state(self):
        """Gets the metadata_state of this BTWorkflowInfo.  # noqa: E501


        :return: The metadata_state of this BTWorkflowInfo.  # noqa: E501
        :rtype: str
        """
        return self._metadata_state

    @metadata_state.setter
    def metadata_state(self, metadata_state):
        """Sets the metadata_state of this BTWorkflowInfo.


        :param metadata_state: The metadata_state of this BTWorkflowInfo.  # noqa: E501
        :type: str
        """

        self._metadata_state = metadata_state

    @property
    def is_discarded(self):
        """Gets the is_discarded of this BTWorkflowInfo.  # noqa: E501


        :return: The is_discarded of this BTWorkflowInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_discarded

    @is_discarded.setter
    def is_discarded(self, is_discarded):
        """Sets the is_discarded of this BTWorkflowInfo.


        :param is_discarded: The is_discarded of this BTWorkflowInfo.  # noqa: E501
        :type: bool
        """

        self._is_discarded = is_discarded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWorkflowInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
