# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWorkspacePartParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'description': 'str',
        'project': 'str',
        'vendor': 'str',
        'title1': 'str',
        'revision': 'str',
        'title2': 'str',
        'title3': 'str',
        'product_line': 'str',
        'configuration': 'str',
        'element_id': 'str',
        'part_number': 'str',
        'part_id': 'str',
        'appearance': 'BTPartAppearanceParams',
        'connection_id': 'str',
        'material': 'BTMaterialParams',
        'custom_property_definitions': 'list[BTCustomPropertyDefinitionParams]',
        'apply_update_to_all_configurations': 'bool',
        'custom_properties': 'list[BTNameValuePair]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'project': 'project',
        'vendor': 'vendor',
        'title1': 'title1',
        'revision': 'revision',
        'title2': 'title2',
        'title3': 'title3',
        'product_line': 'productLine',
        'configuration': 'configuration',
        'element_id': 'elementId',
        'part_number': 'partNumber',
        'part_id': 'partId',
        'appearance': 'appearance',
        'connection_id': 'connectionId',
        'material': 'material',
        'custom_property_definitions': 'customPropertyDefinitions',
        'apply_update_to_all_configurations': 'applyUpdateToAllConfigurations',
        'custom_properties': 'customProperties'
    }

    def __init__(self, name=None, description=None, project=None, vendor=None, title1=None, revision=None, title2=None, title3=None, product_line=None, configuration=None, element_id=None, part_number=None, part_id=None, appearance=None, connection_id=None, material=None, custom_property_definitions=None, apply_update_to_all_configurations=None, custom_properties=None):  # noqa: E501
        """BTWorkspacePartParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._description = None
        self._project = None
        self._vendor = None
        self._title1 = None
        self._revision = None
        self._title2 = None
        self._title3 = None
        self._product_line = None
        self._configuration = None
        self._element_id = None
        self._part_number = None
        self._part_id = None
        self._appearance = None
        self._connection_id = None
        self._material = None
        self._custom_property_definitions = None
        self._apply_update_to_all_configurations = None
        self._custom_properties = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if project is not None:
            self.project = project
        if vendor is not None:
            self.vendor = vendor
        if title1 is not None:
            self.title1 = title1
        if revision is not None:
            self.revision = revision
        if title2 is not None:
            self.title2 = title2
        if title3 is not None:
            self.title3 = title3
        if product_line is not None:
            self.product_line = product_line
        if configuration is not None:
            self.configuration = configuration
        if element_id is not None:
            self.element_id = element_id
        if part_number is not None:
            self.part_number = part_number
        if part_id is not None:
            self.part_id = part_id
        if appearance is not None:
            self.appearance = appearance
        if connection_id is not None:
            self.connection_id = connection_id
        if material is not None:
            self.material = material
        if custom_property_definitions is not None:
            self.custom_property_definitions = custom_property_definitions
        if apply_update_to_all_configurations is not None:
            self.apply_update_to_all_configurations = apply_update_to_all_configurations
        if custom_properties is not None:
            self.custom_properties = custom_properties

    @property
    def name(self):
        """Gets the name of this BTWorkspacePartParams.  # noqa: E501


        :return: The name of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTWorkspacePartParams.


        :param name: The name of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this BTWorkspacePartParams.  # noqa: E501


        :return: The description of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTWorkspacePartParams.


        :param description: The description of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def project(self):
        """Gets the project of this BTWorkspacePartParams.  # noqa: E501


        :return: The project of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this BTWorkspacePartParams.


        :param project: The project of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._project = project

    @property
    def vendor(self):
        """Gets the vendor of this BTWorkspacePartParams.  # noqa: E501


        :return: The vendor of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this BTWorkspacePartParams.


        :param vendor: The vendor of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._vendor = vendor

    @property
    def title1(self):
        """Gets the title1 of this BTWorkspacePartParams.  # noqa: E501


        :return: The title1 of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._title1

    @title1.setter
    def title1(self, title1):
        """Sets the title1 of this BTWorkspacePartParams.


        :param title1: The title1 of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._title1 = title1

    @property
    def revision(self):
        """Gets the revision of this BTWorkspacePartParams.  # noqa: E501


        :return: The revision of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this BTWorkspacePartParams.


        :param revision: The revision of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._revision = revision

    @property
    def title2(self):
        """Gets the title2 of this BTWorkspacePartParams.  # noqa: E501


        :return: The title2 of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._title2

    @title2.setter
    def title2(self, title2):
        """Sets the title2 of this BTWorkspacePartParams.


        :param title2: The title2 of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._title2 = title2

    @property
    def title3(self):
        """Gets the title3 of this BTWorkspacePartParams.  # noqa: E501


        :return: The title3 of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._title3

    @title3.setter
    def title3(self, title3):
        """Sets the title3 of this BTWorkspacePartParams.


        :param title3: The title3 of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._title3 = title3

    @property
    def product_line(self):
        """Gets the product_line of this BTWorkspacePartParams.  # noqa: E501


        :return: The product_line of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this BTWorkspacePartParams.


        :param product_line: The product_line of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def configuration(self):
        """Gets the configuration of this BTWorkspacePartParams.  # noqa: E501


        :return: The configuration of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this BTWorkspacePartParams.


        :param configuration: The configuration of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def element_id(self):
        """Gets the element_id of this BTWorkspacePartParams.  # noqa: E501


        :return: The element_id of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTWorkspacePartParams.


        :param element_id: The element_id of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def part_number(self):
        """Gets the part_number of this BTWorkspacePartParams.  # noqa: E501


        :return: The part_number of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this BTWorkspacePartParams.


        :param part_number: The part_number of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    @property
    def part_id(self):
        """Gets the part_id of this BTWorkspacePartParams.  # noqa: E501


        :return: The part_id of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._part_id

    @part_id.setter
    def part_id(self, part_id):
        """Sets the part_id of this BTWorkspacePartParams.


        :param part_id: The part_id of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._part_id = part_id

    @property
    def appearance(self):
        """Gets the appearance of this BTWorkspacePartParams.  # noqa: E501


        :return: The appearance of this BTWorkspacePartParams.  # noqa: E501
        :rtype: BTPartAppearanceParams
        """
        return self._appearance

    @appearance.setter
    def appearance(self, appearance):
        """Sets the appearance of this BTWorkspacePartParams.


        :param appearance: The appearance of this BTWorkspacePartParams.  # noqa: E501
        :type: BTPartAppearanceParams
        """

        self._appearance = appearance

    @property
    def connection_id(self):
        """Gets the connection_id of this BTWorkspacePartParams.  # noqa: E501


        :return: The connection_id of this BTWorkspacePartParams.  # noqa: E501
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this BTWorkspacePartParams.


        :param connection_id: The connection_id of this BTWorkspacePartParams.  # noqa: E501
        :type: str
        """

        self._connection_id = connection_id

    @property
    def material(self):
        """Gets the material of this BTWorkspacePartParams.  # noqa: E501


        :return: The material of this BTWorkspacePartParams.  # noqa: E501
        :rtype: BTMaterialParams
        """
        return self._material

    @material.setter
    def material(self, material):
        """Sets the material of this BTWorkspacePartParams.


        :param material: The material of this BTWorkspacePartParams.  # noqa: E501
        :type: BTMaterialParams
        """

        self._material = material

    @property
    def custom_property_definitions(self):
        """Gets the custom_property_definitions of this BTWorkspacePartParams.  # noqa: E501


        :return: The custom_property_definitions of this BTWorkspacePartParams.  # noqa: E501
        :rtype: list[BTCustomPropertyDefinitionParams]
        """
        return self._custom_property_definitions

    @custom_property_definitions.setter
    def custom_property_definitions(self, custom_property_definitions):
        """Sets the custom_property_definitions of this BTWorkspacePartParams.


        :param custom_property_definitions: The custom_property_definitions of this BTWorkspacePartParams.  # noqa: E501
        :type: list[BTCustomPropertyDefinitionParams]
        """

        self._custom_property_definitions = custom_property_definitions

    @property
    def apply_update_to_all_configurations(self):
        """Gets the apply_update_to_all_configurations of this BTWorkspacePartParams.  # noqa: E501


        :return: The apply_update_to_all_configurations of this BTWorkspacePartParams.  # noqa: E501
        :rtype: bool
        """
        return self._apply_update_to_all_configurations

    @apply_update_to_all_configurations.setter
    def apply_update_to_all_configurations(self, apply_update_to_all_configurations):
        """Sets the apply_update_to_all_configurations of this BTWorkspacePartParams.


        :param apply_update_to_all_configurations: The apply_update_to_all_configurations of this BTWorkspacePartParams.  # noqa: E501
        :type: bool
        """

        self._apply_update_to_all_configurations = apply_update_to_all_configurations

    @property
    def custom_properties(self):
        """Gets the custom_properties of this BTWorkspacePartParams.  # noqa: E501


        :return: The custom_properties of this BTWorkspacePartParams.  # noqa: E501
        :rtype: list[BTNameValuePair]
        """
        return self._custom_properties

    @custom_properties.setter
    def custom_properties(self, custom_properties):
        """Sets the custom_properties of this BTWorkspacePartParams.


        :param custom_properties: The custom_properties of this BTWorkspacePartParams.  # noqa: E501
        :type: list[BTNameValuePair]
        """

        self._custom_properties = custom_properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWorkspacePartParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
