# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "onshape_client"
VERSION = "0.0.17"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "requests_oauthlib", "ruamel.yaml", "pathlib", "enum34", "pint"]

setup(
    name=NAME,
    version=VERSION,
    description="Onshape REST API",
    author_email="api-support@onshape.zendesk.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Onshape REST API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    The Onshape REST API consumed by all clients.  # noqa: E501
    """
)
