# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBrokenOutEndCondition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'upto_point3d': 'BTVector3d',
        'has_upto_point': 'bool',
        'has_offset': 'bool',
        'offset_distance': 'float',
        'offset_opposite_direction': 'bool',
        'upto_point': 'list[float]',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'upto_point3d': 'uptoPoint3d',
        'has_upto_point': 'hasUptoPoint',
        'has_offset': 'hasOffset',
        'offset_distance': 'offsetDistance',
        'offset_opposite_direction': 'offsetOppositeDirection',
        'upto_point': 'uptoPoint',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, upto_point3d=None, has_upto_point=None, has_offset=None, offset_distance=None, offset_opposite_direction=None, upto_point=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTBrokenOutEndCondition - a model defined in OpenAPI"""  # noqa: E501

        self._upto_point3d = None
        self._has_upto_point = None
        self._has_offset = None
        self._offset_distance = None
        self._offset_opposite_direction = None
        self._upto_point = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if upto_point3d is not None:
            self.upto_point3d = upto_point3d
        if has_upto_point is not None:
            self.has_upto_point = has_upto_point
        if has_offset is not None:
            self.has_offset = has_offset
        if offset_distance is not None:
            self.offset_distance = offset_distance
        if offset_opposite_direction is not None:
            self.offset_opposite_direction = offset_opposite_direction
        if upto_point is not None:
            self.upto_point = upto_point
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def upto_point3d(self):
        """Gets the upto_point3d of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The upto_point3d of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: BTVector3d
        """
        return self._upto_point3d

    @upto_point3d.setter
    def upto_point3d(self, upto_point3d):
        """Sets the upto_point3d of this BTBrokenOutEndCondition.


        :param upto_point3d: The upto_point3d of this BTBrokenOutEndCondition.  # noqa: E501
        :type: BTVector3d
        """

        self._upto_point3d = upto_point3d

    @property
    def has_upto_point(self):
        """Gets the has_upto_point of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The has_upto_point of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: bool
        """
        return self._has_upto_point

    @has_upto_point.setter
    def has_upto_point(self, has_upto_point):
        """Sets the has_upto_point of this BTBrokenOutEndCondition.


        :param has_upto_point: The has_upto_point of this BTBrokenOutEndCondition.  # noqa: E501
        :type: bool
        """

        self._has_upto_point = has_upto_point

    @property
    def has_offset(self):
        """Gets the has_offset of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The has_offset of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: bool
        """
        return self._has_offset

    @has_offset.setter
    def has_offset(self, has_offset):
        """Sets the has_offset of this BTBrokenOutEndCondition.


        :param has_offset: The has_offset of this BTBrokenOutEndCondition.  # noqa: E501
        :type: bool
        """

        self._has_offset = has_offset

    @property
    def offset_distance(self):
        """Gets the offset_distance of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The offset_distance of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: float
        """
        return self._offset_distance

    @offset_distance.setter
    def offset_distance(self, offset_distance):
        """Sets the offset_distance of this BTBrokenOutEndCondition.


        :param offset_distance: The offset_distance of this BTBrokenOutEndCondition.  # noqa: E501
        :type: float
        """

        self._offset_distance = offset_distance

    @property
    def offset_opposite_direction(self):
        """Gets the offset_opposite_direction of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The offset_opposite_direction of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: bool
        """
        return self._offset_opposite_direction

    @offset_opposite_direction.setter
    def offset_opposite_direction(self, offset_opposite_direction):
        """Sets the offset_opposite_direction of this BTBrokenOutEndCondition.


        :param offset_opposite_direction: The offset_opposite_direction of this BTBrokenOutEndCondition.  # noqa: E501
        :type: bool
        """

        self._offset_opposite_direction = offset_opposite_direction

    @property
    def upto_point(self):
        """Gets the upto_point of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The upto_point of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: list[float]
        """
        return self._upto_point

    @upto_point.setter
    def upto_point(self, upto_point):
        """Sets the upto_point of this BTBrokenOutEndCondition.


        :param upto_point: The upto_point of this BTBrokenOutEndCondition.  # noqa: E501
        :type: list[float]
        """

        self._upto_point = upto_point

    @property
    def type_id(self):
        """Gets the type_id of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The type_id of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTBrokenOutEndCondition.


        :param type_id: The type_id of this BTBrokenOutEndCondition.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The connection_source of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTBrokenOutEndCondition.


        :param connection_source: The connection_source of this BTBrokenOutEndCondition.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The export_type_name of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTBrokenOutEndCondition.


        :param export_type_name: The export_type_name of this BTBrokenOutEndCondition.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTBrokenOutEndCondition.  # noqa: E501


        :return: The unknown_class of this BTBrokenOutEndCondition.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTBrokenOutEndCondition.


        :param unknown_class: The unknown_class of this BTBrokenOutEndCondition.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBrokenOutEndCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
